@@ -1,5 +1,5 @@
 from PyQt6.QtCore import Qt, QObject, QEvent, QSize
-from PyQt6.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLabel, QPushButton, QLineEdit, QComboBox, QDialog, QToolButton, QWidgetAction, QCheckBox, QTableWidget, QHeaderView, QApplication, QStyle, QStyledItemDelegate, QScrollArea
+from PyQt6.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLabel, QPushButton, QLineEdit, QComboBox, QDialog, QToolButton, QWidgetAction, QCheckBox, QTableWidget, QHeaderView, QApplication, QStyle, QStyledItemDelegate, QScrollArea, QGridLayout
 from PyQt6.QtGui import QIcon, QTextDocument
 import os
 import sys
@@ -323,7 +323,7 @@ def create_button(
     disabled_background_color = "#2d2d2d",
     disabled_border_width = 2,
     disabled_border_color = "#4a4a4a",
-    maximum_width = 360,
+    maximum_width = None,
     alignment = "center",
     math_expression = False,
     parent = None
@@ -856,7 +856,6 @@ def create_information_message_box(
     message_box.setStyleSheet(style_sheet)
     main_layout = QVBoxLayout(message_box)
     message_box.setLayout(main_layout)
-    main_layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
     main_layout.setContentsMargins(left_margin, top_margin, right_margin, bottom_margin)
     main_layout.setSpacing(spacing)
     text_label = create_label(
@@ -879,6 +878,8 @@ def create_information_message_box(
         parent = message_box
     )
     main_layout.addWidget(text_label)
+    button_grid = QGridLayout()
+    main_layout.addLayout(button_grid)
     accept_button = create_button(
         text = button_text,
         font_family = button_font_family,
@@ -904,7 +905,7 @@ def create_information_message_box(
         disabled_border_width = button_disabled_border_width,
         disabled_border_color = button_disabled_border_color
     )
-    main_layout.addWidget(accept_button)
+    button_grid.addWidget(accept_button)
     accept_button.clicked.connect(message_box.accept)
     return message_box
     
@@ -973,7 +974,6 @@ def create_confirmation_message_box(
     confirm_message_box.setStyleSheet(style_sheet)
     main_layout = QVBoxLayout(confirm_message_box)
     confirm_message_box.setLayout(main_layout)
-    main_layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
     main_layout.setContentsMargins(left_margin, top_margin, right_margin, bottom_margin)
     main_layout.setSpacing(spacing)
     text_label = create_label(
@@ -996,9 +996,9 @@ def create_confirmation_message_box(
         parent = confirm_message_box
     )
     main_layout.addWidget(text_label)
-    buttons_layout = QHBoxLayout()
-    main_layout.addLayout(buttons_layout)
-    buttons_layout.setSpacing(button_spacing)
+    buttons_grid = QGridLayout()
+    main_layout.addLayout(buttons_grid)
+    buttons_grid.setSpacing(button_spacing)
     confirm_button = create_button(
         text = "Sí",
         font_family = button_font_family,
@@ -1024,7 +1024,7 @@ def create_confirmation_message_box(
         disabled_border_width = button_disabled_border_width,
         disabled_border_color = button_disabled_border_color
     )
-    buttons_layout.addWidget(confirm_button)
+    buttons_grid.addWidget(confirm_button, 0, 0)
     confirm_button.clicked.connect(confirm_message_box.accept)
     decline_button = create_button(
         text = "No",
@@ -1051,7 +1051,7 @@ def create_confirmation_message_box(
         disabled_border_width = button_disabled_border_width,
         disabled_border_color = button_disabled_border_color
     )
-    buttons_layout.addWidget(decline_button)
+    buttons_grid.addWidget(decline_button, 0, 1)
     decline_button.clicked.connect(confirm_message_box.reject)
     return confirm_message_box
 
